about summary refs log tree commit diff
path: root/tools
diff options
context:
space:
mode:
authorVincent Ambo <mail@tazj.in>2020-06-11T23·14+0100
committertazjin <mail@tazj.in>2020-06-11T23·20+0000
commitd570fbbad3b74a38625d4cb2b0772f91aa6185ce (patch)
treef6b48073a1ae192f190639987c2da59000e82225 /tools
parent4e3d3b6c22dc5df86e163c9799b26b8346422f40 (diff)
chore(tools/emacs): Update window management configuration for frog r/913
Change-Id: I848d4c1d58a81a66800f25459fee8f85d3f269f6
Reviewed-on: https://cl.tvl.fyi/c/depot/+/64
Reviewed-by: tazjin <mail@tazj.in>
Diffstat (limited to 'tools')
-rw-r--r--tools/emacs/config/desktop.el30
1 files changed, 15 insertions, 15 deletions
diff --git a/tools/emacs/config/desktop.el b/tools/emacs/config/desktop.el
index aefff0125f..edbdbafc90 100644
--- a/tools/emacs/config/desktop.el
+++ b/tools/emacs/config/desktop.el
@@ -216,23 +216,23 @@
   (shell-command "xrandr --output HDMI1 --right-of eDP1 --auto --primary")
   (exwm-randr-refresh))
 
 ;; Layouts for nugget (desktop)
 
-(defun randr-nugget-layout-right-only ()
-  "Use only the right screen on nugget."
+(defun randr-frog-layout-right-only ()
+  "Use only the right screen on frog."
   (interactive)
-  (set-randr-config `(("DP-2" ,(number-sequence 0 9))))
-  (shell-command "xrandr --output DP-0 --off")
-  (shell-command "xrandr --output DP-2 --auto --primary"))
+  (set-randr-config `(("DP-1" ,(number-sequence 0 9))))
+  (shell-command "xrandr --output DP-2 --off")
+  (shell-command "xrandr --output DP-1 --auto --primary"))
 
-(defun randr-nugget-layout-both ()
-  "Use the left and right screen on nugget."
+(defun randr-frog-layout-both ()
+  "Use the left and right screen on frog."
   (interactive)
-  (set-randr-config `(("DP-0" 1 2 3 4 5)
-                      ("DP-2" 6 7 8 9 0)))
+  (set-randr-config `(("DP-2" 1 2 3 4 5)
+                      ("DP-1" 6 7 8 9 0)))
 
-  (shell-command "xrandr --output DP-0 --auto --primary --left-of DP-2")
-  (shell-command "xrandr --output DP-2 --auto --right-of DP-0"))
+  (shell-command "xrandr --output DP-2 --auto --primary --left-of DP-1")
+  (shell-command "xrandr --output DP-1 --auto --right-of DP-2"))
 
 (pcase (s-trim (shell-command-to-string "hostname"))
   ("vauxhall"
@@ -240,9 +240,9 @@
    (exwm-input-set-key (kbd "s-m a") #'randr-vauxhall-layout-all)
    (exwm-input-set-key (kbd "s-m w") #'randr-vauxhall-layout-wide-only))
 
-  ("nugget"
-   (exwm-input-set-key (kbd "s-m b") #'randr-nugget-layout-both)
-   (exwm-input-set-key (kbd "s-m r") #'randr-nugget-layout-right-only)))
+  ("frog"
+   (exwm-input-set-key (kbd "s-m b") #'randr-frog-layout-both)
+   (exwm-input-set-key (kbd "s-m r") #'randr-frog-layout-right-only)))
 
 (exwm-randr-enable)
@@ -216,23 +216,23 @@
   (exwm-randr-refresh))
 
-;; Layouts for nugget (desktop)
+;; Layouts for frog (desktop)
 